==> kubernetes-model-1.0.43-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DoneableThirdPartyResource.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Function;

public class DoneableThirdPartyResource extends ThirdPartyResourceFluentImpl<DoneableThirdPartyResource> implements Doneable<ThirdPartyResource>, ThirdPartyResourceFluent<DoneableThirdPartyResource>{


    private final ThirdPartyResourceBuilder builder;    private final Function<ThirdPartyResource, ThirdPartyResource> function;
    public DoneableThirdPartyResource ( Function<ThirdPartyResource, ThirdPartyResource> function){
    this.builder=new ThirdPartyResourceBuilder(this);this.function=function;
}
    public DoneableThirdPartyResource ( ThirdPartyResource item,  Function<ThirdPartyResource, ThirdPartyResource> function){
    this.builder=new ThirdPartyResourceBuilder(this, item);this.function=function;
}
    public DoneableThirdPartyResource ( ThirdPartyResource item){
    this.builder=new ThirdPartyResourceBuilder(this, item);this.function=new Function<ThirdPartyResource, ThirdPartyResource>() {
    public ThirdPartyResource apply(ThirdPartyResource item) {
        return item;
    }
}
;
}

    public ThirdPartyResource done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DoneableThirdPartyResource.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Function;

public class DoneableThirdPartyResource extends ThirdPartyResourceFluentImpl<DoneableThirdPartyResource> implements Doneable<ThirdPartyResource>,ThirdPartyResourceFluent<DoneableThirdPartyResource>{


    private final ThirdPartyResourceBuilder builder;    private final Function<ThirdPartyResource, ThirdPartyResource> function;
    public DoneableThirdPartyResource ( Function<ThirdPartyResource, ThirdPartyResource> function){
    this.builder=new ThirdPartyResourceBuilder(this);this.function=function;
}
    public DoneableThirdPartyResource ( ThirdPartyResource item,  Function<ThirdPartyResource, ThirdPartyResource> function){
    this.builder=new ThirdPartyResourceBuilder(this);this.function=function;
}
    public DoneableThirdPartyResource ( ThirdPartyResource item){
    this.builder=new ThirdPartyResourceBuilder(this, item);this.function=new Function<ThirdPartyResource, ThirdPartyResource>() {
    public ThirdPartyResource apply(ThirdPartyResource item) {
        return item;
    }
}
;
}

    public ThirdPartyResource done(){
     return function.apply(builder.build());
}


}
